@@ -15,12 +15,12 @@ import pop.loader
 
 try:
     HAS_TEST = False
-    from asynctest.mock import create_autospec, Mock
+    from asynctest.mock import create_autospec
 
     HAS_TEST = True
 except (ImportError, ModuleNotFoundError):
     try:
-        from unittest.mock import create_autospec as mock_create_autospec, Mock
+        from unittest.mock import create_autospec as mock_create_autospec
 
         HAS_TEST = True
 
@@ -280,6 +280,9 @@ class MockHub(_LazyPop):
         hub.sub.mod.attr  # mock
     """
 
+    def __getitem__(self, item):
+        return getattr(self, item)
+
     def _mock_function(self, f: pop.contract.Contracted) -> Callable:
         afunc = create_autospec(strip_hub(f.func), spec_set=True)
         afunc.__signature__ = f.signature
